Chromium Code Reviews

Unified Diff: trunk/src/media/base/video_renderer.h

Issue 14320005: Revert 194993 "Remove reference counting from media::VideoDecode..." (Closed) Base URL: svn://svn.chromium.org/chrome/
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
« no previous file with comments | « trunk/src/media/base/video_decoder.h ('k') | trunk/src/media/filters/decrypting_video_decoder.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: trunk/src/media/base/video_renderer.h
===================================================================
--- trunk/src/media/base/video_renderer.h (revision 195011)
+++ trunk/src/media/base/video_renderer.h (working copy)
@@ -5,6 +5,8 @@
#ifndef MEDIA_BASE_VIDEO_RENDERER_H_
#define MEDIA_BASE_VIDEO_RENDERER_H_
+#include <list>
+
#include "base/callback.h"
#include "base/memory/ref_counted.h"
#include "base/time.h"
@@ -22,6 +24,8 @@
class MEDIA_EXPORT VideoRenderer {
public:
+ typedef std::list<scoped_refptr<VideoDecoder> > VideoDecoderList;
+
// Used to update the pipeline's clock time. The parameter is the time that
// the clock should not exceed.
typedef base::Callback<void(base::TimeDelta)> TimeCB;
@@ -35,8 +39,8 @@
VideoRenderer();
virtual ~VideoRenderer();
// Initialize a VideoRenderer with |stream|, executing |init_cb| upon
// completion.
//
// |statistics_cb| is executed periodically with video rendering stats, such
// as dropped frames.
@@ -54,6 +58,7 @@
//
// |get_duration_cb| is used to query the media duration.
virtual void Initialize(const scoped_refptr<DemuxerStream>& stream,
+ const VideoDecoderList& decoders,
const PipelineStatusCB& init_cb,
const StatisticsCB& statistics_cb,
const TimeCB& time_cb,
@@ -35,8 +39,8 @@
VideoRenderer();
virtual ~VideoRenderer();
- // Initialize a VideoRenderer with |stream|, executing |init_cb| upon
- // completion.
+ // Initialize a VideoRenderer with the given DemuxerStream and
+ // VideoDecoderList, executing |init_cb| callback upon completion.
//
// |statistics_cb| is executed periodically with video rendering stats, such
« no previous file with comments | « trunk/src/media/base/video_decoder.h ('k') | trunk/src/media/filters/decrypting_video_decoder.h » ('j') | no next file with comments »

Powered by Google App Engine